--[[
	Author:  Azmaedus US-Arathor
	Version: 0.1
	compatible with game version 6.0.3
	
	Change Log
	----------
	11/29/2014 - 0.1 	Creation of addon
	11/29/2014 - 0.1.1 	Support for tier 1, 2, and 3 garrison (Outpost, Fort, and Garrison)
	12/01/2014 - r8		1st commit to wowace.com (alpha)
	12/02/2014 - r9		Added multi-dimensional table to hold music filename references
	
	Known Bugs
	----------
	11/29/2014 - r8		ReloadUI doesn't trigger event to play music.
]]

-- Load the Ace libraries --
GarrisonJukeBox = LibStub("AceAddon-3.0"):NewAddon("GarrisonJukeBox", "AceConsole-3.0", "AceEvent-3.0")
local L = LibStub("AceLocale-3.0"):GetLocale("GarrisonJukeBox")

-- globals
local gVersion = "0.1a"
local gMusicPlaying = false
local LUNARFALL = 971

-- Create the default settings for this addon --
local defaults = { 
    profile =  {
		shuffle = false,
		-- expac = {}, (removed) no idea why I put this here O.o
		music = {},
	},
}

-- temporary static music table; will be changed to a 2 dimensional table
local wowmusic = {
	"Sound\\Music\\ZoneMusic\\Azuremyst\\AI_DraeneiWalkUni05.mp3",
	"Sound\\Music\\ZoneMusic\\Azuremyst\\AI_DraeneiWalkUni06.mp3",
	"Sound\\Music\\ZoneMusic\\Azuremyst\\AI_DraeneiWalkUni07r.mp3",
	"Sound\\Music\\ZoneMusic\\Azuremyst\\AI_DraeneiWalkUni08r.mp3",
	"Sound\\Music\\ZoneMusic\\Azuremyst\\AI_ExodarIntro01.mp3",
	"Sound\\Music\\ZoneMusic\\Azuremyst\\AI_ExodarWalkUni01.mp3",
	"Sound\\Music\\ZoneMusic\\Azuremyst\\AI_ExodarWalkUni02.mp3",
	"Sound\\Music\\ZoneMusic\\Azuremyst\\AI_ExodarWalkUni03.mp3",
	"Sound\\Music\\ZoneMusic\\Azuremyst\\AI_NagaWalkUni01.mp3",
	"Sound\\Music\\ZoneMusic\\Azuremyst\\AI_NagaWalkUni02.mp3",
	"Sound\\Music\\ZoneMusic\\Azuremyst\\AI_NagaWalkUni03.mp3",
	"Sound\\Music\\ZoneMusic\\Azuremyst\\AI_NagaWalkUni04.mp3",
	"Sound\\Music\\ZoneMusic\\Azuremyst\\AI_NagaWalkUni05.mp3",
	"Sound\\Music\\ZoneMusic\\Azuremyst\\AI_OwlkinWalkUni01.mp3",
	"Sound\\Music\\ZoneMusic\\Azuremyst\\AI_OwlkinWalkUni02.mp3",
	"Sound\\Music\\ZoneMusic\\Azuremyst\\AV_DraeneiWalkUni01.mp3",
	"Sound\\Music\\ZoneMusic\\Azuremyst\\AV_DraeneiWalkUni02.mp3",
	"Sound\\Music\\ZoneMusic\\Azuremyst\\AV_DraeneiWalkUni02r.mp3",
	"Sound\\Music\\ZoneMusic\\Azuremyst\\AV_DraeneiWalkUni03.mp3",
	"Sound\\Music\\ZoneMusic\\Azuremyst\\AV_DraeneiWalkUni03r.mp3",
	"Sound\\Music\\ZoneMusic\\Azuremyst\\AV_DraeneiWalkUni04.mp3",
	"Sound\\Music\\ZoneMusic\\Bloodmyst\\BI_SatyrWalkUni01r.mp3",
	"Sound\\Music\\ZoneMusic\\Bloodmyst\\BI_SatyrWalkUni02.mp3",
	"Sound\\Music\\ZoneMusic\\Bloodmyst\\BI_SatyrWalkUni03.mp3",
	"Sound\\Music\\ZoneMusic\\Bloodmyst\\BI_SatyrWalkUni04.mp3",
	"Sound\\Music\\ZoneMusic\\Bloodmyst\\BI_SatyrWalkUni05.mp3",
}
local maxmusic = table.getn(wowmusic)

-- multidimensional table holding music file names
local musictable = {
	["wow"] = {},
	["bc"] = {
		"Sound\\Music\\ZoneMusic\\Azuremyst\\AI_DraeneiWalkUni05.mp3",
		"Sound\\Music\\ZoneMusic\\Azuremyst\\AI_DraeneiWalkUni06.mp3",
		"Sound\\Music\\ZoneMusic\\Azuremyst\\AI_DraeneiWalkUni07r.mp3",
		"Sound\\Music\\ZoneMusic\\Azuremyst\\AI_DraeneiWalkUni08r.mp3",
		"Sound\\Music\\ZoneMusic\\Azuremyst\\AI_ExodarIntro01.mp3",
		"Sound\\Music\\ZoneMusic\\Azuremyst\\AI_ExodarWalkUni01.mp3",
		"Sound\\Music\\ZoneMusic\\Azuremyst\\AI_ExodarWalkUni02.mp3",
		"Sound\\Music\\ZoneMusic\\Azuremyst\\AI_ExodarWalkUni03.mp3",
		"Sound\\Music\\ZoneMusic\\Azuremyst\\AI_NagaWalkUni01.mp3",
		"Sound\\Music\\ZoneMusic\\Azuremyst\\AI_NagaWalkUni02.mp3",
		"Sound\\Music\\ZoneMusic\\Azuremyst\\AI_NagaWalkUni03.mp3",
		"Sound\\Music\\ZoneMusic\\Azuremyst\\AI_NagaWalkUni04.mp3",
		"Sound\\Music\\ZoneMusic\\Azuremyst\\AI_NagaWalkUni05.mp3",
		"Sound\\Music\\ZoneMusic\\Azuremyst\\AI_OwlkinWalkUni01.mp3",
		"Sound\\Music\\ZoneMusic\\Azuremyst\\AI_OwlkinWalkUni02.mp3",
		"Sound\\Music\\ZoneMusic\\Azuremyst\\AV_DraeneiWalkUni01.mp3",
		"Sound\\Music\\ZoneMusic\\Azuremyst\\AV_DraeneiWalkUni02.mp3",
		"Sound\\Music\\ZoneMusic\\Azuremyst\\AV_DraeneiWalkUni02r.mp3",
		"Sound\\Music\\ZoneMusic\\Azuremyst\\AV_DraeneiWalkUni03.mp3",
		"Sound\\Music\\ZoneMusic\\Azuremyst\\AV_DraeneiWalkUni03r.mp3",
		"Sound\\Music\\ZoneMusic\\Azuremyst\\AV_DraeneiWalkUni04.mp3",
		"Sound\\Music\\ZoneMusic\\Bloodmyst\\BI_SatyrWalkUni01r.mp3",
		"Sound\\Music\\ZoneMusic\\Bloodmyst\\BI_SatyrWalkUni02.mp3",
		"Sound\\Music\\ZoneMusic\\Bloodmyst\\BI_SatyrWalkUni03.mp3",
		"Sound\\Music\\ZoneMusic\\Bloodmyst\\BI_SatyrWalkUni04.mp3",
		"Sound\\Music\\ZoneMusic\\Bloodmyst\\BI_SatyrWalkUni05.mp3",
	},
	["wotlk"] = {},
	["cata"] = {},
	["mop"] = {},
	["wod"] = {},
}

-- Create the options variable to use in the config screen --
local options = {
	name = "Garrison JukeBox",
	handler = GarrisonJukeBox,
	type = "group",
	args = {
		shuffle = {
			type = "toggle",
			name = L["Shuffle"],
			desc = L["Randomly plays the music from your playlist."],

			set = function(info, value)
				-- Save variable
				GarrisonJukeBox.db.profile.shuffle = value
			end,

			get = function(info)
				return GarrisonJukeBox.db.profile.shuffle
			end,

			width = "full",
			order = 10,
		},
		expac = {
			type = "select",
			name = L["Expansion"],
			desc = L["Select the expansion."],
			style = "dropdown",
			values = {
--				[1] = L["World of Warcraft"],
--				[2] = L["The Burning Crusade"],
--				[3] = L["Wrath of the Lich King"],
--				[4] = L["Cataclysm"],
--				[5] = L["Mists of Pandaria"],
--				[6] = L["Warlords of Dreanor"],
				L["World of Warcraft"],
				L["The Burning Crusade"],
				L["Wrath of the Lich King"],
				L["Cataclysm"],
				L["Mists of Pandaria"],
				L["Warlords of Dreanor"],
			},
			set = "SetExpac",
			get = "GetExpac",
			width = "normal",
			order = 10,
		},
		music = {
			type = "select",
			dialogControl = 'LSM30_Sound',
			name = L["Music"],
			desc = L["Select the music."],
			style = "dropdown",
			--values = AceGUIWidgetLSMlists.sound,
			set = "SetMusic",
			get = "GetMusic",
			width = "normal",
			order = 10,
		},
	},
}

-- Expac get/set functions
function GarrisonJukeBox:SetExpac(info, value)
	GarrisonJukeBox.db.profile.expac = value
end

function GarrisonJukeBox:GetExpac(info)
	return GarrisonJukeBox.db.profile.expac
end

-- Music get/set functions
function GarrisonJukeBox:SetMusic(info, value)
	GarrisonJukeBox.db.profile.music = value
end

function GarrisonJukeBox:GetMusic(info)
	return GarrisonJukeBox.db.profile.music
end

function GarrisonJukeBox:OnLoad(frame)
	GarrisonJukeBox:RegisterEvent("ZONE_CHANGED_NEW_AREA", "OnEvent")
	GarrisonJukeBox:RegisterEvent("PLAYER_ENTERING_WORLD", "OnEvent")
	GarrisonJukeBox:RegisterEvent("PLAYER_LOGIN", "OnEvent")
	GarrisonJukeBox:RegisterEvent("ZONE_CHANGED_INDOORS", "OnEvent")
	GarrisonJukeBox:RegisterEvent("ZONE_CHANGED", "OnEvent")
	
	self:Print(L["Garrison JukeBox"] .. " " .. gVersion .. " " .. L["loaded!"])
end  

function GarrisonJukeBox:OnInitialize()
	GarrisonJukeBox.db = LibStub("AceDB-3.0"):New("GarrisonJukeBoxDB", defaults, "Default")
	--GarrisonJukeBox.db.args.expac.SetValue(1)
	
	LibStub("AceConfig-3.0"):RegisterOptionsTable("GarrisonJukeBoxDB", options)
	  
	self.optionsFrame = LibStub("AceConfigDialog-3.0"):AddToBlizOptions("GarrisonJukeBoxDB", "Garrison JukeBox")

	self:RegisterChatCommand("gjb", "ChatCommand")
	self:RegisterChatCommand("garrisonjukebox", "ChatCommand")
	  
	self:Print(L["Garrison JukeBox"] .. " " .. gVersion .. " " .. L["initialized!"])
end

function GarrisonJukeBox:OnEvent(event, ...)
	if event == "ZONE_CHANGED_NEW_AREA" or event == "PLAYER_ENTERING_WORLD" or event == "PLAYER_LOGIN" or event == "ZONE_CHANGED_INDOORS" or event == "ZONE_CHANGED" then
		if GetCurrentMapAreaID() == LUNARFALL then
			if gMusicPlaying == false then
				local id = random(1, maxmusic)
				StopMusic()
				PlayMusic(wowmusic[id])
				self:Print("Playing: " .. wowmusic[id])
				gMusicPlaying = true
			end
		else 
			if gMusicPlaying == true then
				StopMusic()
				gMusicPlaying = false
			end
		end
	end
end

function GarrisonJukeBox:ChatCommand(input)
  -- Open dialog if no parameters, else do something with the parameters
  if not input or input:trim() == "" then
    InterfaceOptionsFrame_OpenToCategory(self.optionsFrame)
  else
    LibStub("AceConfigCmd-3.0").HandleCommand(SpamageMeters, "gjb", "GarrisonJukeBox", input)
  end
end